# v0

## v0.1

### v0.1.1 - 2022-06-05

- Fixed wrong minimum Python version in package metadata.
- Updated README.md with more information about the package.

### v0.1.0 - 2022-06-05

Initial public release